@@ -5,9 +5,9 @@
 #' See the README on
 #' \href{https://github.com/biodosetools-team/biodosetools/}{GitHub}
 #'
-#' @docType package
-#' @name biodosetools
-NULL
+#' @aliases biodosetools-package
+#' @keywords internal
+"_PACKAGE"
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if (getRversion() >= "2.15.1") {
