@@ -18,7 +18,7 @@ mod_estimation_dicent_ui <- function(id, label) {
       box(
         width = 5,
         title = span(
-          "Curve fitting data options",
+          HTML("1. Curve fitting data options"),
           help_modal_button(
             ns("help_fit_data"),
             ns("help_fit_data_modal")
@@ -81,12 +81,12 @@ mod_estimation_dicent_ui <- function(id, label) {
                 )
               ),
               widget_sep(),
-              actionButton(
-                ns("button_gen_table"),
-                class = "options-button",
-                style = "margin-left: -10px; margin-bottom: 0px;",
-                label = "Generate tables"
-              ),
+              # actionButton(
+              #   ns("button_gen_table"),
+              #   class = "options-button",
+              #   style = "margin-left: -10px; margin-bottom: 0px;",
+              #   label = "Generate tables"
+              # ),
               br(),
               br(),
               widget_label("Coefficients"),
@@ -173,14 +173,104 @@ mod_estimation_dicent_ui <- function(id, label) {
             rHandsontableOutput(ns("fit_var_cov_mat"))
           )
         )
-      )
+      ),
+      conditionalPanel(
+        condition = "!input.load_fit_data_check",
+        ns = ns,
+      box(
+        width = 7,
+        title = "Irradiation conditions",
+        status = "primary",
+        collapsible = TRUE,
+        col_6(
+          class = "col-inner-textinput-left",
+          textInput(
+            inputId = ns("irr_cond_irradiator_name"),
+            label = "Name of the irradiator used",
+            placeholder = NULL
+          ),
+          textAreaInput(
+            inputId = ns("irr_cond_radiation_quality"),
+            label = "Radiation quality",
+            placeholder = "e.g. Cs-137, Co-60, X-ray, etc."
+          ),
+          numericInput(
+            ns("irr_cond_dose_rate"),
+            label = "Dose rate (Gy/min)",
+            step=0.1,
+            value = NA,
+            min=0
+          ),
+          selectInput(
+            ns("irr_cond_dose_quantity"),
+            label = "Dose quantity",
+            choices = c("Please choose"="", "air kerma", "dose to water", "dose to blood")
+          ),
+          selectInput(
+            ns("cal_air_water"),
+            label = "Calibration of the source",
+            choices = c("Please choose"="", "air kerma", "water")
+          ),
+          selectInput(
+            ns("irrad_air_water"),
+            label = "Irradiation medium",
+            choices = c("Please choose"="", "air", "water")
+          ),
+          numericInput(
+            ns("max_dose_curve"),
+            label = "Maximum dose curve (Gy)",
+            step=0.1,
+            value = NA,
+            min=0
+          )
+        )
+        ,
+        col_6(
+          class = "col-inner-textinput-right",
+          textInput(
+            inputId = ns("irr_cond_whole_blood"),
+            label = "Whole blood or isolated lymphocytes",
+            placeholder = NULL
+          ),
+          numericInput(
+            ns("irr_cond_temperature"),
+            label = "Temperature (\u00B0C) during irradiation",
+            step=1,
+            value = NA,
+            min=0,
+            max = 40
+          ),
+          numericInput(
+            ns("irr_cond_time"),
+            label = "Time of incubation (h) at 37(\u00B0C) after irradiation"  ,
+            step=1,
+            value = NA,
+            min=0
+          ),
+          textAreaInput(
+            inputId = ns("irr_cond_beam_characteristics"),
+            label = "Beam characteristics",
+            placeholder = "Beam quality indicators, filtration (X-rays), energy (Gamma rays), ..."
+          ),
+          selectInput(
+            ns("scoring_method"),
+            label = "Scoring method",
+            choices = c("Please choose"="", "manual", "auto")
+          ),
+          textInput(
+            inputId = ns("origin_curve"),
+            label = "Origin of the curve",
+            placeholder = "e.g. own, IAEA ..."
+          )
+        )
+      ))
     ),
     fluidRow(
       # Box: Data input options ----
       box(
         width = 5,
         title = span(
-          "Data input options",
+            HTML("2. Data input options"),
           help_modal_button(
             ns("help_cases_data"),
             ns("help_cases_data_modal")
@@ -231,11 +321,11 @@ mod_estimation_dicent_ui <- function(id, label) {
             conditionalPanel(
               condition = "!input.load_case_data_check",
               ns = ns,
-              # numericInput(
-              #   ns("num_cases"),
-              #   label = "Number of cases",
-              #   value = 1
-              # ),
+               numericInput(
+                 ns("num_cases"),
+                 label = "Number of cases",
+                 value = 1
+               ),
               numericInput(
                 ns("num_aberrs"),
                 label = "Maximum number of dicentrics per cell",
@@ -270,7 +360,7 @@ mod_estimation_dicent_ui <- function(id, label) {
       col_7_inner(
         box(
           width = 12,
-          title = "Data input",
+          title = HTML("3. Data input"),
           status = "primary",
           collapsible = TRUE,
 
@@ -292,7 +382,7 @@ mod_estimation_dicent_ui <- function(id, label) {
         box(
           width = 12,
           title = span(
-            "Dose estimation options",
+            HTML("4. Dose estimation options"),
             help_modal_button(
               ns("help_estimation_options"),
               ns("help_estimation_options_modal")
@@ -342,7 +432,6 @@ mod_estimation_dicent_ui <- function(id, label) {
               )
             )
           ),
-
           # Type of exposure selection
           div(
             class = "side-widget-tall",
@@ -395,6 +484,7 @@ mod_estimation_dicent_ui <- function(id, label) {
           ),
           widget_sep(),
 
+
           # Partial-body error method selection
           div(
             class = "side-widget-tall",
@@ -526,6 +616,45 @@ mod_estimation_dicent_ui <- function(id, label) {
               )
             )
           ),
+          # include badge dose for the calculation of incidence rate ratio
+          conditionalPanel(
+            condition = "input.assessment_select == 'whole-body'",
+            ns = ns,
+             conditionalPanel(
+               condition = "input.num_cases < 2",
+               ns = ns,
+            conditionalPanel(
+              condition = "input.exposure_select == 'acute'",
+              ns = ns,
+              br(),
+              br(),
+              div(
+                class = "side-widget-tall",
+                awesomeCheckbox(
+                  inputId = ns("badge_dose_check"),
+                  status = "info",
+                  label = "Suspected (e.g. badge) dose",
+                  value = FALSE,
+                  width = "175px"
+                )
+              ),
+              widget_sep(),
+              # Input badge dose
+              div(
+                class = "side-widget-tall",
+                conditionalPanel(
+                  condition = "input.badge_dose_check",
+                  ns = ns,
+                  numericInput(
+                    ns("badge_dose"),
+                    label = "Suspected dose (Gy)",
+                    value = 0.25,
+                    step = 0.01,
+                    width = "175px"
+                  )
+                )))),
+            br()
+          ),
           conditionalPanel(
             condition = "input.assessment_select == 'whole-body'",
             ns = ns,
@@ -541,19 +670,47 @@ mod_estimation_dicent_ui <- function(id, label) {
             class = "options-button",
             label = "Estimate dose"
           )
+        ),
+        col_12(
+          # tabBox: Estimation results ----
+          uiOutput(ns("estimation_results_ui"))
         )
       )
     ),
     fluidRow(
-      col_6_inner(
-        # tabBox: Estimation results ----
-        uiOutput(ns("estimation_results_ui")),
+
+      # Box: Plot curves ----
+      box(
+        width = 12,
+        title = "Results plot",
+        status = "success",
+        collapsible = TRUE,
+
+        # Plot
+        plotOutput(ns("plot")),
+        # Download plot
+        downloadButton(
+          ns("save_plot"),
+          class = "results-button side-widget-download",
+          label = "Save plot"
+        ),
+        div(
+          class = "side-widget-format",
+          selectInput(
+            ns("save_plot_format"),
+            label = NULL,
+            width = "75px",
+            choices = list(".jpg", ".png",".pdf"),
+            selected = ".jpg"
+          )
+        )
+      ),
 
         # Box: Export data and results ----
         box(
-          width = 12,
+          width = 6,
           title = span(
-            "Save results",
+            HTML("5. Save results"),
             help_modal_button(
               ns("help_fit_data_save"),
               ns("help_fit_data_save_modal")
@@ -579,6 +736,21 @@ mod_estimation_dicent_ui <- function(id, label) {
             label = "Comments",
             placeholder = "Comments to be included on report"
           ),
+          downloadButton(
+            ns("save_data"),
+            class = "export-button side-widget-download",
+            label = "Save data"
+          ),
+          div(
+            class = "side-widget-format",
+            selectInput(
+              ns("save_data_format"),
+              label = NULL,
+              width = "75px",
+              choices =  list(".rds", ".xlsx"),
+              selected = ".rds"
+            )
+          ),
 
           # Download report
           downloadButton(
@@ -597,33 +769,8 @@ mod_estimation_dicent_ui <- function(id, label) {
             )
           )
         )
-      ),
-      # Box: Plot curves ----
-      box(
-        width = 6,
-        title = "Curve plot",
-        status = "success",
-        collapsible = TRUE,
-
-        # Plot
-        plotOutput(ns("plot")),
-        # Download plot
-        downloadButton(
-          ns("save_plot"),
-          class = "results-button side-widget-download",
-          label = "Save plot"
-        ),
-        div(
-          class = "side-widget-format",
-          selectInput(
-            ns("save_plot_format"),
-            label = NULL,
-            width = "75px",
-            choices = list(".png", ".pdf"),
-            selected = ".png"
-          )
-        )
       )
+
     )
-  )
+
 }
